@@ -1360,7 +1360,8 @@ guint AddDel::treeview_append_column(const Glib::ustring& title, Gtk::CellRender
   pViewColumn->set_resizable();
 
   //Set a faily sensible default width:
-  pViewColumn->set_min_width(100);
+  pViewColumn->set_fixed_width(100); //This is the only way to set the width, so we need to set it as resizable again immediately afterwards.
+  pViewColumn->set_resizable();
 
   //Save the extra ID, using the title if the column_id is empty:
   pViewColumn->set_column_id( (column_id.empty() ? title : column_id) );
@@ -1616,8 +1617,9 @@ bool AddDel::row_has_duplicates(const Gtk::TreeModel::iterator& iter) const
     {
       Gtk::TreeModel::Row row = *iter;
 
-      //We can't just use ValueBase, because Glib::ValueBase has no operator==, because there is no g_value_equal
-      //Glib::ValueBase value_this_row;
+      //We can't just use Value, because Gnome::Gda::Value has no operator==, because there is no g_value_equal
+      //Gnome::Gda::Value value_this_row;
+      //TODO: Actually, Gnome::Gda::Value has an operator==
       //iter->get_value(col, value_this_row);
 
       Glib::ustring value_text;
@@ -1639,8 +1641,9 @@ bool AddDel::row_has_duplicates(const Gtk::TreeModel::iterator& iter) const
         if(iterCheck != iter) //Don't compare the row with itself
         {
           Gtk::TreeModel::Row check_row = *iterCheck;
-          ////Glib::ValueBase has no operator==, because there is no g_value_equal
-          //Glib::ValueBase value_check_row;
+          ////Gnome::Gda::Value has no operator==, because there is no g_value_equal
+          //Gnome::Gda::Value value_check_row;
+          //TODO: Actually, Gnome::Gda::Value has an operator==
           //iterCheck->get_value(col, value_check_row);
           //
           //if(value_check_row == value_this_row)
